@@ -3,7 +3,7 @@ library(kappalab)
 mu <- capacity(c(0:13,13,13)/13)
 a <- Mobius(mu)
 stopifnot(abs(normalize(normalize(mu))@data - normalize(mu)@data) < 1e-6)
-stopifnot(abs(mu@data - dual(dual(mu))@data) < 1e-6)
+stopifnot(abs(mu@data - conjugate(conjugate(mu))@data) < 1e-6)
 stopifnot(abs(mu@data - zeta(Mobius(mu))@data) < 1e-6)
 stopifnot(abs(a@data - Mobius(zeta(a))@data) < 1e-6)
 stopifnot(abs(veto(mu) - veto(a)) < 1e-6)
